@@ -22,8 +22,10 @@ class Broker:
         self.utils = utils if utils is not None else Utils()
 
         # Set sandbox mode
+        self._sandbox_str = ""
         if config["sandbox_mode"]:
             self.api.set_sandbox_mode(True)
+            self._sandbox_str = " (sandbox mode)"
 
         # Load markets
         markets = self.api.load_markets()
@@ -31,12 +33,17 @@ class Broker:
         self.base_currency = config["base_currency"]
 
         # Create AutoData instance
-        self.autodata = AutoData(data_source="ccxt", exchange=self.exchange)
+        self.autodata = AutoData(
+            data_source="ccxt",
+            exchange=self.exchange,
+            api=self.api,
+        )
 
     def __repr__(self):
         return (
             f"AutoTrader-{self.exchange[0].upper()}"
             + f"{self.exchange[1:].lower()} interface"
+            + self._sandbox_str
         )
 
     def __str__(self):
@@ -53,10 +60,7 @@ class Broker:
 
     def place_order(self, order: Order, **kwargs) -> None:
         """Disassemble order_details dictionary to place order."""
-        # TODO - include params from kwargs, also need to get params from Order
-        # Call order to set order time
         order()
-
         # Submit order to broker
         if order.order_type == "modify":
             placed_order = self._modify_order(order)
@@ -66,18 +70,25 @@ class Broker:
         ]:
             raise NotImplementedError(
                 f"Order type '{order.order_type}' has not "
-                + "been implemented for CCXT yet."
+                + "been implemented for the CCXT interface yet."
             )
         else:
+            # Regular order
             side = "buy" if order.direction > 0 else "sell"
-            placed_order = self.api.createOrder(
-                symbol=order.instrument,
-                type=order.order_type,
-                side=side,
-                amount=order.size,
-                price=order.order_limit_price,
-                params=order.ccxt_params,
-            )
+            try:
+                # Submit the order
+                placed_order = self.api.createOrder(
+                    symbol=order.instrument,
+                    type=order.order_type,
+                    side=side,
+                    amount=order.size,
+                    price=order.order_limit_price,
+                    params=order.ccxt_params,
+                )
+            except Exception as e:
+                # An error occured, return the exception
+                placed_order = e
+
         return placed_order
 
     def get_orders(
@@ -87,15 +98,15 @@ class Broker:
         # TODO - add exception handling
         if order_status == "open":
             # Fetch open orders (waiting to be filled)
-            orders = self.api.fetchOpenOrders(instrument)
+            orders = self.api.fetchOpenOrders(instrument, **kwargs)
 
         elif order_status == "cancelled":
             # Fetch cancelled orders
-            orders = self.api.fetchCanceledOrders(instrument)
+            orders = self.api.fetchCanceledOrders(instrument, **kwargs)
 
         elif order_status == "closed":
             # Fetch closed orders
-            orders = self.api.fetchClosedOrders(instrument)
+            orders = self.api.fetchClosedOrders(instrument, **kwargs)
 
         # Convert
         orders = self._convert_list(orders, item_type="order")
@@ -104,7 +115,10 @@ class Broker:
 
     def cancel_order(self, order_id: int, **kwargs) -> None:
         """Cancels order by order ID."""
-        cancelled_order = self.api.cancelOrder(id=order_id, **kwargs)
+        try:
+            cancelled_order = self.api.cancelOrder(id=order_id, **kwargs)
+        except Exception as e:
+            cancelled_order = e
         return cancelled_order
 
     def get_trades(self, instrument: str = None, **kwargs) -> dict:
@@ -264,12 +278,15 @@ class Broker:
         """Modify the size, type and price of an existing order."""
         # TODO - support changing order_type, not sure how it will be carried
         side = "buy" if order.direction > 0 else "sell"
-        modified_order = self.api.editOrder(
-            id=order.related_orders[0],
-            symbol=order.instrument,
-            side=side,
-            type=None,
-            amount=order.size,
-            price=order.order_limit_price,
-        )
+        try:
+            modified_order = self.api.editOrder(
+                id=order.related_orders[0],
+                symbol=order.instrument,
+                side=side,
+                type=None,
+                amount=order.size,
+                price=order.order_limit_price,
+            )
+        except Exception as e:
+            modified_order = e
         return modified_order
