@@ -84,8 +84,8 @@ def get_broker_config(
         if broker.lower() not in supported_brokers:
             raise Exception(f"Unsupported broker: '{broker}'")
 
-        if environment.lower() not in ["live", "paper"]:
-            raise Exception("Trading environment can either be 'live' or 'paper'.")
+        if broker != "ccxt" and environment.lower() not in ["live", "paper"]:
+            raise Exception("Trading environment must either be 'live' or 'paper'.")
 
         # Live trading
         if broker.lower() == "oanda":
@@ -156,6 +156,15 @@ def get_broker_config(
         elif broker.lower() == "ccxt":
             try:
                 config_data = global_config[broker_key.upper()]
+
+                # Select config based on environment
+                if environment.lower() in config_data:
+                    config_data = config_data[environment.lower()]
+                elif "mainnet" in config_data and environment.lower() == "live":
+                    config_data = config_data["mainnet"]
+                elif "testnet" in config_data and environment.lower() == "paper":
+                    config_data = config_data["testnet"]
+
                 api_key = config_data["api_key"] if "api_key" in config_data else None
                 secret = config_data["secret"] if "secret" in config_data else None
                 currency = (
@@ -291,7 +300,14 @@ def get_data_config(feed: str, global_config: dict = None, **kwargs) -> dict:
         )
 
     elif feed.lower() == "ccxt":
-        config["exchange"] = exchange
+        # Try add authentication with global config
+        if global_config is not None:
+            environment = kwargs["environment"] if "environment" in kwargs else "paper"
+            config = get_broker_config(
+                broker=f"{feed.lower()}:{exchange}", environment=environment
+            )
+        else:
+            config["exchange"] = exchange
 
     return config
 
@@ -1115,7 +1131,11 @@ class DataStream:
         Parameters
         ----------
         timestamp : datetime, optional
-            The current timestamp. The default is None.
+            The current timestamp, which can be used to fetch
+            data if need. Note that look-ahead is checked for in
+            AutoTrader.autobot, so the data returned from this
+            method can include all available data. The default is
+            None.
 
         Returns
         -------
@@ -1350,7 +1370,7 @@ class DataStream:
         processed_strategy_data: dict = None,
     ) -> dict:
         """Returns a dictionary of the current bars of the products being
-        traded, based on the up-to-date data.
+        traded, based on the up-to-date data passed from autobot.
 
         Parameters
         ----------
@@ -1365,7 +1385,7 @@ class DataStream:
         Returns
         -------
         dict
-            A dictionary of bars, keyed by the product name.
+            A dictionary of OHLC bars, keyed by the product name.
 
         Notes
         -----
